@@ -108,8 +108,8 @@ module.exports = {
       instrumentationKey: "72804848-dc30-4856-8245-4fa1450b041f",
     },
     algolia: {
-      appId: 'BH4D9OD16A',
-      apiKey: '539391a0be386508c6a80cb2bca8ebfe',
+      appId: 'XIR4RB3TM1',
+      apiKey: '15c5f4340520612ed98fe21d15882029',
       indexName: 'ohmyposh',
     },
   },
