@@ -25,7 +25,7 @@ module.exports = {
         "config-sample",
         "config-title",
         "config-colors",
-        "config-text-style",
+        "config-templates",
         "config-transient",
         "config-tooltips",
         "config-fonts"
@@ -51,6 +51,7 @@ module.exports = {
         "git",
         "poshgit",
         "golang",
+        "haskell",
         "ipify",
         "java",
         "julia",
@@ -75,6 +76,7 @@ module.exports = {
         "terraform",
         "text",
         "time",
+        "ui5tooling",
         "wakatime",
         "wifi",
         "winreg",
